@@ -34,7 +34,7 @@ import playerfactory as PlayerFactory
 import mediasong as MediaSong
 
 # The current version of Kap
-_VERSION = "0.2.1"
+_VERSION = "0.3.0"
 
 
 class Kap(wx.Frame):
@@ -370,7 +370,7 @@ class Kap(wx.Frame):
         mli = MediaLibraryDialogue.MediaLibraryDialogue(self, \
             self.__database.searchPaths())
         mli.ShowModal()
-        if mli.blIsSettingsDirty:
+        if mli.blSaveSettings:
             self.StatusBar.SetStatusText("Updating Media Library...", \
                 self.__GENERAL_STATUS_FIELD)
             songsInLibrary = self.__database.buildLibrary( \
@@ -391,7 +391,7 @@ class Kap(wx.Frame):
             self.__additionalPlayerArguements, self.__trackRefreshRate, \
                 self.__searchRefreshRate, self.__removeFromPlayList)
         kd.ShowModal()
-        if kd.blIsSettingsDirty:
+        if kd.blSaveSettings:
             # Update the player arguments
             self.__additionalPlayerArguements = kd.playerArguments()
             self.__playerFactory.destroy()
@@ -441,12 +441,9 @@ class Kap(wx.Frame):
     def __updateSearchResults(self, event):
         """ Updates the search results window.
 
-         wx.Event event: is the event object, method only runs if the ID is
-           self.__ID_SEARCH_TIMER
+         wx.Event event: is the event object (Not Used)
         """
-        if not event.GetId() == self.__ID_SEARCH_TIMER:
-            return
-        elif self.__database.searchFinished():
+        if self.__database.searchFinished():
             self.__searchWindow.clearSearchResults()
             songs = self.__database.songsFound()
             for song in songs:
