@@ -28,8 +28,10 @@ class KapDialogue(wx.Dialog):
     """
      ATTRIBUTES
     """
+    # Indicates if the settings should be saved
+    blSaveSettings = False
     # Indicates if the a setting has changed
-    blIsSettingsDirty = False
+    __blIsSettingsDirty = False
     # Minimum refresh rate for updating any window, in milliseconds
     __MINIMUM_REFRESH_RATE = 0
     # Maximum refresh rate for updating any window, in milliseconds
@@ -198,7 +200,7 @@ class KapDialogue(wx.Dialog):
 
     def __onMarkSettingsDirty(self, event):
         """ Marks the settings as being dirty. """
-        self.blIsSettingsDirty = True
+        self.__blIsSettingsDirty = True
 
     def __onSaveSettings(self, event):
         """ User wants to save the settings.
@@ -206,7 +208,7 @@ class KapDialogue(wx.Dialog):
          Indicates to save the settings by marking them as dirty.
          wx.Event event: is the event object (Not Used)
         """
-        self.blIsSettingsDirty = True
+        self.blSaveSettings = True
         self.Show(False)
         self.Destroy()
 
@@ -218,11 +220,13 @@ class KapDialogue(wx.Dialog):
            discard all of their changes.
          wx.Event event: is the event object (Not Used)
         """
-        if self.blIsSettingsDirty:
-            answer = wx.MessageBox("Kap settings have changed!", \
-                "Confirm Close", wx.YES_NO | wx.ICON_QUESTION)
+        if self.__blIsSettingsDirty:
+            answer = wx.MessageBox("Close and save new settings?", \
+                "Settings Changed",  wx.CANCEL | wx.YES_NO | wx.ICON_QUESTION)
             if answer == wx.YES:
-                self.blIsSettingsDirty = False
+                self.blSaveSettings = True
+            elif answer == wx.NO:
+                self.blSaveSettings = False
             else:
                 return
         self.Show(False)
