@@ -28,8 +28,10 @@ class MediaLibraryDialogue(wx.Dialog):
     """
      ATTRIBUTES
     """
+    # Indicates if the settings should be saved
+    blSaveSettings = False
     # Indicates if the a setting has changed
-    blIsSettingsDirty = False
+    __blIsSettingsDirty = False
 
     """
      Event IDs
@@ -47,7 +49,7 @@ class MediaLibraryDialogue(wx.Dialog):
            for media.
         """
         wx.Dialog.__init__(self, parent, wx.NewId(), "Media Library")
-        self.__createControls(directoryPaths)
+        self.__UpdateControls(directoryPaths)
         self.__bindEvents()
         self.__doLayout()
 
@@ -58,26 +60,24 @@ class MediaLibraryDialogue(wx.Dialog):
         """
         return self.__lstBxDirectories.GetItems()
 
-    def __createControls(self, directoryPaths):
-        """ Creates all the user controls for the dialogue.
+    def __UpdateControls(self, directoryPaths):
+        """ Updates all the user controls for the dialogue.
 
          list[string] directoryPaths: are the paths to each directory to
            search for media.
         """
-        # Create Directory Listing
+        # Update Directory Listing
         self.__lstBxDirectories = wx.ListBox(self, -1, \
-            wx.DefaultPosition, wx.DefaultSize, "", wx.LB_SINGLE, \
+            wx.DefaultPosition, wx.DefaultSize, directoryPaths, wx.LB_SINGLE, \
             wx.DefaultValidator, "Directory List Box")
-        for directoryPath in directoryPaths:
-            self.__lstBxDirectories.Append(directoryPath)
         self.__bttnAddDirectory = wx.Button(self, \
             self.__ID_ADD_DIRECTORY, "Add Directory")
         self.__bttnRemoveDirectory = wx.Button(self, \
             self.__ID_REMOVE_DIRECTORY, "Remove Directory")
 
-        # Create interface direction buttons
-        self.__bttnCreateLibrary = wx.Button(self, wx.ID_OK, \
-            "Create Library")
+        # Update interface direction buttons
+        self.__bttnUpdateLibrary = wx.Button(self, wx.ID_OK, \
+            "Update Library")
         self.__bttnClose = wx.Button(self, wx.ID_CANCEL, "Close")
 
     def __bindEvents(self):
@@ -86,7 +86,7 @@ class MediaLibraryDialogue(wx.Dialog):
             self.__onAddDirectory)
         wx.EVT_BUTTON(self, self.__ID_REMOVE_DIRECTORY, \
             self.__onRemoveDirectory)
-        wx.EVT_BUTTON(self, wx.ID_OK, self.__onCreateLibrary)
+        wx.EVT_BUTTON(self, wx.ID_OK, self.__onUpdateLibrary)
         wx.EVT_BUTTON(self, wx.ID_CANCEL, self.__onClose)
         wx.EVT_CLOSE(self, self.__onClose)
 
@@ -105,11 +105,11 @@ class MediaLibraryDialogue(wx.Dialog):
 
         # Dialogue Buttons
         self.__stdDlgBttnSzrButtons = wx.StdDialogButtonSizer()
-        self.__stdDlgBttnSzrButtons.AddButton(self.__bttnCreateLibrary)
+        self.__stdDlgBttnSzrButtons.AddButton(self.__bttnUpdateLibrary)
         self.__stdDlgBttnSzrButtons.AddButton(self.__bttnClose)
         self.__stdDlgBttnSzrButtons.Realize()
 
-        # Create Interface
+        # Update Interface
         self.__bxSzrInterface = wx.BoxSizer(wx.VERTICAL)
         self.__bxSzrInterface.AddSpacer(15)
         self.__bxSzrInterface.Add(self.__bxSzrDirectories, 1, wx.EXPAND | \
@@ -132,7 +132,7 @@ class MediaLibraryDialogue(wx.Dialog):
         if (drdlgAddDirectory.ShowModal() == wx.ID_OK):
             path = drdlgAddDirectory.GetPath()
             self.__lstBxDirectories.Append(path)
-            self.blIsSettingsDirty = True
+            self.__blIsSettingsDirty = True
 
     def __onRemoveDirectory(self, event):
         """ Allows a user to remove a directory from the search paths.
@@ -143,15 +143,15 @@ class MediaLibraryDialogue(wx.Dialog):
         """
         index = self.__lstBxDirectories.GetSelection()
         self.__lstBxDirectories.Delete(index)
-        self.blIsSettingsDirty = True
+        self.__blIsSettingsDirty = True
 
-    def __onCreateLibrary(self, event):
-        """ User wants to create the library.
+    def __onUpdateLibrary(self, event):
+        """ User wants to Update the library.
 
-         Creates a new library database, by marking the settings as dirty.
+         Updates a new library database, by marking the settings as dirty.
          wx.Event event: is the event object (Not Used)
         """
-        self.blIsSettingsDirty = True
+        self.blSaveSettings = True
         self.Show(False)
         self.Destroy()
 
@@ -163,11 +163,13 @@ class MediaLibraryDialogue(wx.Dialog):
            discard all of their changes.
          wx.Event event: is the event object (Not Used)
         """
-        if self.blIsSettingsDirty:
-            answer = wx.MessageBox("Media library paths have changed!", \
-                "Confirm Close", wx.YES_NO | wx.ICON_QUESTION)
+        if self.__blIsSettingsDirty:
+            answer = wx.MessageBox("Close and save new paths?", \
+                "Media Paths Changed", wx.YES_NO | wx.CANCEL | wx.ICON_QUESTION)
             if answer == wx.YES:
-                self.blIsSettingsDirty = False
+                self.blSaveSettings = True
+            elif answer == wx.NO:
+                self.blSaveSettings = False
             else:
                 return
         self.Show(False)
