@@ -31,11 +31,15 @@ class SearchWindow(wx.Panel):
      ATTRIBUTES
     """
     # A list of the MediaSong objects displayed in the results panel.
-    __displayedResults = []
+    __searchResults = []
     # Is the width of the media column.
     __MEDIA_WIDTH = 50
     # Approximate width of the vertical scroll bar
     __VERTICAL_SCROLL_BAR = 25
+    # Maximum number of results to display at once
+    __MAXIMUM_DISPLAYED_RESULTS = 50
+    # Current index position displayed
+    __displayedResultsStartIndex = None
 
     """
      EVENT ID
@@ -54,6 +58,12 @@ class SearchWindow(wx.Panel):
     __ID_TITLE_COLUMN = 1
     # Column ID for the artist title in the results window
     __ID_ARTIST_COLUMN = 2
+    # Previous search results page
+    __ID_PREVIOUS = wx.NewId()
+    # Next search results page
+    __ID_NEXT = wx.NewId()
+    # Search result page indicator
+    __ID_PAGES = wx.NewId()
 
     def __init__(self, parent, searchAudio=True, searchVideo=True):
         """ Default constructor
@@ -99,6 +109,16 @@ class SearchWindow(wx.Panel):
         self.__lstCtlSearchResults.InsertColumn(self.__ID_ARTIST_COLUMN, \
             "Artist")
 
+        # Large list navigation
+        self.__bttnPrevious = wx.Button(self, self.__ID_PREVIOUS, \
+            "Previous Page")
+        self.__bttnPrevious.Enable(False)
+        self.__spnCtrlPage = wx.SpinCtrl(self, self.__ID_PAGES, \
+            style=wx.TE_READONLY)
+        self.__spnCtrlPage.SetRange(0, 0)
+        self.__bttnNext = wx.Button(self, self.__ID_NEXT, "Next Page")
+        self.__bttnNext.Enable(False)
+
     def __bindEvents(self):
         """ Connects all the needed events.
 
@@ -108,6 +128,11 @@ class SearchWindow(wx.Panel):
         wx.EVT_LIST_INSERT_ITEM(self, self.ID_SEARCH_RESULTS, \
             self.__onListInsertItem)
 
+        # Search Navigation Events
+        wx.EVT_BUTTON(self, self.__ID_PREVIOUS, self.__onPreviousSearch)
+        wx.EVT_BUTTON(self, self.__ID_NEXT, self.__onNextSearch)
+        wx.EVT_SPINCTRL(self, self.__ID_PAGES, self.__OnPageChanged)
+
     def __doLayout(self):
         """ Creates a visually pleasing look for the controls.
 
@@ -119,8 +144,19 @@ class SearchWindow(wx.Panel):
         self.__bxSzrSearchEntry.Add(self.__srchCtrlSearch, 1, wx.EXPAND | \
             wx.ALL | wx.FIXED_MINSIZE, 3)
 
+        # Search Navigation Layout
+        self.__bxSzrSearchNavigation = wx.BoxSizer(wx.HORIZONTAL)
+        self.__bxSzrSearchNavigation.AddSpacer(5)
+        self.__bxSzrSearchNavigation.Add(self.__spnCtrlPage, 0, wx.ALL, 3)
+        self.__bxSzrSearchNavigation.AddSpacer(5)
+        self.__bxSzrSearchNavigation.Add(self.__bttnPrevious, 1, wx.EXPAND | \
+            wx.ALL | wx.FIXED_MINSIZE, 3)
+        self.__bxSzrSearchNavigation.AddSpacer(5)
+        self.__bxSzrSearchNavigation.Add(self.__bttnNext, 1, wx.EXPAND | \
+            wx.ALL | wx.FIXED_MINSIZE, 3)
+
         # Search Result Layout
-        self.__bxSzrSearchResults = wx.BoxSizer(wx.HORIZONTAL)
+        self.__bxSzrSearchResults = wx.BoxSizer(wx.VERTICAL)
         self.__bxSzrSearchResults.Add(self.__lstCtlSearchResults, 1, \
             wx.EXPAND | wx.ALL, 3)
 
@@ -131,6 +167,7 @@ class SearchWindow(wx.Panel):
         self.__bxSzrInterface.AddSpacer(5)
         self.__bxSzrInterface.Add(self.__bxSzrSearchResults, 1, wx.EXPAND | \
             wx.ALL)
+        self.__bxSzrInterface.Add(self.__bxSzrSearchNavigation, 0)
         self.SetSizer(self.__bxSzrInterface)
 
     def searchTerms(self):
@@ -170,7 +207,8 @@ class SearchWindow(wx.Panel):
             if next == -1:
                 return selection
 
-            selection.append(self.__displayedResults[next])
+            selection.append(self.__searchResults[next + \
+                self.__displayedResultsStartIndex])
             current = next
 
     def __getNextSelectedSong(self, current):
@@ -185,33 +223,44 @@ class SearchWindow(wx.Panel):
 
     def clearSearchResults(self):
         """ Clears the display result window """
-        del self.__displayedResults[:]
+        del self.__searchResults[:]
         self.__lstCtlSearchResults.DeleteAllItems()
+        self.__displayedResultsStartIndex = None
 
     def addSearchResult(self, result):
         """ Adds a search result to display for the user.
 
          MediaSong result: is the song to add.
         """
-        self.__displayedResults.append(result)
-        index = len(self.__displayedResults) - 1
+        self.__searchResults.append(result)
+        index = len(self.__searchResults) - 1
+        if self.__displayedResultsStartIndex is None:
+            self.__addResultItem(index, result)
+            self.__displayedResultsStartIndex = 0
+        elif len(self.__searchResults) <= self.__MAXIMUM_DISPLAYED_RESULTS:
+            self.__addResultItem(index, result)
+        self.__updateNavigationButtons()
+
+    def __addResultItem(self, index, song):
+        """ Adds the song from the search results to the display. """
+
         # Title Information
         item = wx.ListItem()
         item.SetId(index)
         item.SetColumn(self.__ID_TITLE_COLUMN)
-        item.SetText(result.title)
+        item.SetText(song.title)
         self.__lstCtlSearchResults.InsertItem(item)
         # Artist Information
         item = wx.ListItem()
         item.SetId(index)
         item.SetColumn(self.__ID_ARTIST_COLUMN)
-        item.SetText(result.artist)
+        item.SetText(song.artist)
         self.__lstCtlSearchResults.SetItem(item)
         # Video Information
         item = wx.ListItem()
         item.SetId(index)
         item.SetColumn(self.__ID_MEDIA_COLUMN)
-        if result.blIsVideo:
+        if song.blIsVideo:
             item.SetText("Video")
         else:
             item.SetText("Audio")
@@ -234,3 +283,62 @@ class SearchWindow(wx.Panel):
             width / 2)
         self.__lstCtlSearchResults.SetColumnWidth(self.__ID_MEDIA_COLUMN, \
             self.__MEDIA_WIDTH)
+
+    def __onPreviousSearch(self, event):
+        """ Adjusts the result display to the previous self.__MAXIMUM_DISPLAYED_RESULTS searches. """
+        self.__displayedResultsStartIndex -= self.__MAXIMUM_DISPLAYED_RESULTS
+        self.__displaySearchResultsFromIndex(self.__displayedResultsStartIndex)
+        self.__updateNavigationButtons()
+
+    def __onNextSearch(self, event):
+        """ Adjusts the result display to the next self.__MAXIMUM_DISPLAYED_RESULTS searches. """
+        self.__displayedResultsStartIndex += self.__MAXIMUM_DISPLAYED_RESULTS
+        self.__displaySearchResultsFromIndex(self.__displayedResultsStartIndex)
+        self.__updateNavigationButtons()
+
+    def __displaySearchResultsFromIndex(self, startIndex):
+        """ Display's the results from a starting index. """
+        self.__lstCtlSearchResults.DeleteAllItems()
+        resultIndex = 0
+        if (self.__displayedResultsStartIndex + \
+                self.__MAXIMUM_DISPLAYED_RESULTS) < len(self.__searchResults):
+            endIndex = (self.__MAXIMUM_DISPLAYED_RESULTS + startIndex)
+        else:
+            endIndex = len(self.__searchResults)
+        for index in range(startIndex, endIndex):
+            self.__addResultItem(resultIndex, self.__searchResults[index])
+            index += 1
+            resultIndex += 1
+
+    def __updateNavigationButtons(self):
+        """ Updates the navigation buttons based on the search results. """
+        if (self.__displayedResultsStartIndex + \
+                self.__MAXIMUM_DISPLAYED_RESULTS) > len(self.__searchResults):
+            self.__bttnNext.Enable(False)
+        elif len(self.__searchResults) > self.__MAXIMUM_DISPLAYED_RESULTS:
+            self.__bttnNext.Enable(True)
+        else:
+            self.__bttnNext.Enable(False)
+
+        if self.__displayedResultsStartIndex < 1:
+            self.__bttnPrevious.Enable(False)
+        else:
+            self.__bttnPrevious.Enable(True)
+
+        if self.__displayedResultsStartIndex is not None:
+            self.__spnCtrlPage.SetRange(1, len(self.__searchResults) / \
+                self.__MAXIMUM_DISPLAYED_RESULTS + 1)
+            self.__spnCtrlPage.SetValue(self.__displayedResultsStartIndex / \
+                self.__MAXIMUM_DISPLAYED_RESULTS + 1)
+
+    def __OnPageChanged(self, event):
+        """ Hangles the changes in pages from the user  """
+        currentPage = self.__displayedResultsStartIndex / \
+                self.__MAXIMUM_DISPLAYED_RESULTS + 1
+        newPage = self.__spnCtrlPage.GetValue()
+        if currentPage > newPage:
+            self.__onPreviousSearch(event)
+        elif currentPage < newPage:
+            self.__onNextSearch(event)
+        else:
+            return
\ No newline at end of file
